@@ -36,3 +36,35 @@ sub index : Private {
 }
 
 1;
+
+=head1 NAME
+
+App::Cinema::Controller::Login - A controller that handles a request for login.
+
+=head1 SYNOPSIS
+
+You can call its actions in any template files either
+
+    <a HREF="[% Catalyst.uri_for('/login') %]">login</a>
+    
+or
+
+    <a HREF="[% base %]login">login</a>
+
+=head1 DESCRIPTION
+
+This is A controller that handles a request for login.
+
+=head2 Methods
+
+=over 12
+
+=item C<index>
+
+This private action is used to perform login action.
+
+=back
+
+=head1 AUTHOR
+
+Jeff Mo - L<http://jandc.co.cc/>
